python-wsl
==========

This is a Python3 library for reading and writing WSL data.

WSL is a text format for relational databases:
http://jstimpfle.de/projects/wsl/main.html

This is an experimental library; significant changes are to be expected.

Documentation
-------------

The documentation is available at
http://jstimpfle.de/projects/python-wsl/doc/

To generate the documentation from the source code

$ make -C doc/ html

This needs the python3-sphinx package (under Debian) and the Sphinx autodoc
extension, and the relatively new `napoleon` extension (which is in Debian
since Debian stretch)
